PerconaPgClusterDataSourcePostgresCluster

Struct PerconaPgClusterDataSourcePostgresCluster 

pub struct PerconaPgClusterDataSourcePostgresCluster {
    pub affinity: Option<PerconaPgClusterDataSourcePostgresClusterAffinity>,
    pub cluster_name: Option<String>,
    pub cluster_namespace: Option<String>,
    pub options: Option<Vec<String>>,
    pub priority_class_name: Option<String>,
    pub repo_name: String,
    pub resources: Option<PerconaPgClusterDataSourcePostgresClusterResources>,
    pub tolerations: Option<Vec<PerconaPgClusterDataSourcePostgresClusterTolerations>>,
}
Defines a pgBackRest data source that can be used to pre-populate the PostgreSQL data directory for a new PostgreSQL cluster using a pgBackRest restore. The PGBackRest field is incompatible with the PostgresCluster field: only one data source can be used for pre-populating a new PostgreSQL cluster

Fields

affinity: Option<PerconaPgClusterDataSourcePostgresClusterAffinity>

Scheduling constraints of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node

cluster_name: Option<String>

The name of an existing PostgresCluster to use as the data source for the new PostgresCluster. Defaults to the name of the PostgresCluster being created if not provided.

cluster_namespace: Option<String>

The namespace of the cluster specified as the data source using the clusterName field. Defaults to the namespace of the PostgresCluster being created if not provided.

options: Option<Vec<String>>

Command line options to include when running the pgBackRest restore command. https://pgbackrest.org/command.html#command-restore

priority_class_name: Option<String>

Priority class name for the pgBackRest restore Job pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/

repo_name: String

The name of the pgBackRest repo within the source PostgresCluster that contains the backups that should be utilized to perform a pgBackRest restore when initializing the data source for the new PostgresCluster.

resources: Option<PerconaPgClusterDataSourcePostgresClusterResources>

Resource requirements for the pgBackRest restore Job.

tolerations: Option<Vec<PerconaPgClusterDataSourcePostgresClusterTolerations>>

Tolerations of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration